@@ -3,7 +3,6 @@ require(sasLM)
 f1 = yield ~ block + N*P*K
 GLM(f1, npk)
 REG(f1, npk)
-ANOVA(f1, npk)
 EMS(f1, npk)
 lr(f1, npk)
 lr0(f1, npk)
@@ -11,7 +10,6 @@ lr0(f1, npk)
 f1b = yield ~ block + N*P*K - 1
 GLM(f1b, npk[-1,])
 REG(f1b, npk[-1,])
-ANOVA(f1b, npk[-1,])
 EMS(f1b, npk[-1,])
 lr(f1b, npk[-1,])
 lr0(f1b, npk[-1,])
@@ -19,7 +17,6 @@ lr0(f1b, npk[-1,])
 f2 = weight ~ feed
 GLM(f2, chickwts)
 REG(f2, chickwts)
-ANOVA(f2, chickwts)
 EMS(f2, chickwts)
 lr(f2, chickwts)
 lr0(f2, chickwts)
@@ -29,7 +26,6 @@ GLM(f3, CO2)
 REG(f3, CO2)
 lr(f3, CO2)
 lr0(f3, CO2)
-ANOVA(f3, CO2)
 EMS(f3, CO2)
 aov1(f3, CO2)
 aov2(f3, CO2)
